TimeZoneSettings class
Controls PostgreSQL date/time materialization.
The default is deliberately the small, exact UTC path. Named IANA lookup is only performed when useIanaTimeZoneDatabase is explicitly enabled and forceDecodeTimestamptzAsUTC is false.
Constructors
- TimeZoneSettings(String value, {bool forceDecodeTimestamptzAsUTC = true, bool forceDecodeTimestampAsUTC = true, bool forceDecodeDateAsUTC = true, bool useIanaTimeZoneDatabase = false, PgTimeZoneDatabaseScope ianaTimeZoneDatabaseScope = PgTimeZoneDatabaseScope.latestAll, bool throwOnDateTimeInfinity = false})
-
const
- TimeZoneSettings.utc()
-
const
Properties
- forceDecodeDateAsUTC → bool
-
Materialize
dateat UTC midnight.final - forceDecodeTimestampAsUTC → bool
-
Materialize
timestamp without time zonewith UTC civil components.final - forceDecodeTimestamptzAsUTC → bool
-
Materialize
timestamptzas UTC (the allocation-minimal default).final - hashCode → int
-
The hash code for this object.
no setterinherited
- ianaTimeZoneDatabaseScope → PgTimeZoneDatabaseScope
-
Full historical or compact recent transition database.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- throwOnDateTimeInfinity → bool
-
Throw instead of returning null for PostgreSQL date/time infinities.
final
- useIanaTimeZoneDatabase → bool
-
Use the vendored IANA transition database for a named value.
final
- value → String
-
PostgreSQL/IANA location name, for example
America/Sao_Paulo.final
Methods
-
copyWith(
{String? value, bool? forceDecodeTimestamptzAsUTC, bool? forceDecodeTimestampAsUTC, bool? forceDecodeDateAsUTC, bool? useIanaTimeZoneDatabase, PgTimeZoneDatabaseScope? ianaTimeZoneDatabaseScope, bool? throwOnDateTimeInfinity}) → TimeZoneSettings -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited